| Title: | Distinctiveness Centrality |
|---|---|
| Description: | Calculates Distinctiveness Centrality in social networks. For formulas and descriptions, see Fronzetti Colladon and Naldi (2020) <doi:10.1371/journal.pone.0233276>. |
| Authors: | Andrea Fronzetti Colladon [aut, cre], Luis Maas [aut] |
| Maintainer: | Andrea Fronzetti Colladon <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.1 |
| Built: | 2026-05-31 10:41:15 UTC |
| Source: | https://github.com/iandreafc/distinctiveness-r |
The main function; oversees the calculations of Distinctiveness Centrality
distinctiveness( G, alpha = 1, normalize = FALSE, measures = c("D1", "D2", "D3", "D4", "D5") )distinctiveness( G, alpha = 1, normalize = FALSE, measures = c("D1", "D2", "D3", "D4", "D5") )
G |
the given graph |
alpha |
the given exponent for penalizing connections to highly connected nodes |
normalize |
when TRUE, the function normalizes output metrics to allow for comparison with other graphs. Defaults to FALSE |
measures |
the measures of Distinctiveness Centrality to be computed |
a data frame containing the specified calculated measures of Distinctiveness Centrality for the given graph
g <- igraph::erdos.renyi.game(20, 50, type = "gnm", directed = FALSE) plot(g) distinctiveness(g) distinctiveness(g, alpha = list(2, 1, 3, 2, 4), measures = c("D1", "D3", "D4")) g_dir <- igraph::erdos.renyi.game(20, 50, type = "gnm", directed = TRUE) plot(g_dir) distinctiveness(g_dir) distinctiveness(g_dir, alpha = 2, normalize = TRUE, measures = c("D2", "D5"))g <- igraph::erdos.renyi.game(20, 50, type = "gnm", directed = FALSE) plot(g) distinctiveness(g) distinctiveness(g, alpha = list(2, 1, 3, 2, 4), measures = c("D1", "D3", "D4")) g_dir <- igraph::erdos.renyi.game(20, 50, type = "gnm", directed = TRUE) plot(g_dir) distinctiveness(g_dir) distinctiveness(g_dir, alpha = 2, normalize = TRUE, measures = c("D2", "D5"))